/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.java.net
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.impl;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.ThreadSafe;
import org.openide.filesystems.FileObject;
import it.tidalwave.actor.annotation.Actor;
import it.tidalwave.actor.annotation.MessageListener;
import it.tidalwave.integritychecker.FileDiscoveredMessage;
import it.tidalwave.integritychecker.FileScanRequestMessage;
import lombok.extern.slf4j.Slf4j;

/***********************************************************************************************************************
 * 
 * @stereotype Actor
 * 
 * An actor for discovering files in a given folder.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Actor @ThreadSafe @Slf4j
public class FileObjectDiscoveryActor 
  {
    /*******************************************************************************************************************
     * 
     * 
     * 
     ******************************************************************************************************************/
    @MessageListener
    public void discover (final @Nonnull FileScanRequestMessage message)
      {
        log.debug("discover({})", message);

        for (final FileObject child : message.getFolder().getChildren())
          {
            if (message.getFilter().accepts(child))
              {
                (child.isFolder() ? FileScanRequestMessage.forFile(child).withFilter(message.getFilter()) 
                                  : FileDiscoveredMessage.forFile(child)).send();
              }
          }
      }
  }
